@@ -502,7 +502,6 @@ our %codepages = (
     'whois.nic.hu'       => 'iso-8859-1',
     'whois.dns.pt'       => 'iso-8859-1',
     'whois.net.ua'       => 'koi8-u',
-    'whois.com.ua'       => 'koi8-u',
     'whois.biz.ua'       => 'koi8-u',
     'whois.co.ua'        => 'koi8-u',
     'whois.dn.ua'        => 'koi8-u',
@@ -672,7 +671,7 @@ our %notfound = (
     'whois2.afilias-grs.net'    => '^NOT FOUND',
     'whois.aitdomains.com'      => '^No match for',
     'whois.alldomains.com'      => '^No match for',
-    'whois.centralnic.com'      => '^This domain name may be available for',
+    'whois.centralnic.com'      => '^DOMAIN NOT FOUND',
     'whois.communigal.net'      => '^NOT FOUND',
     'whois.desertdevil.com'     => 'No match for domain',
     'whois.directi.com'         => 'No Match for',
